Returns the IDs of all documents currently loaded in the server.
Examples
if (FALSE) { # interactive()
server <- sync_server()
create_document(server)
list_documents(server)
server$close()
}
Returns the IDs of all documents currently loaded in the server.
if (FALSE) { # interactive()
server <- sync_server()
create_document(server)
list_documents(server)
server$close()
}